post

Function post 

pub async fn post(url: &str, token: Option<&str>, body: &str) -> Result<String>
Send one JSON-RPC message to an endpoint and return the response body.

Used by the headless start to proxy to a running GUI (G17), and by tests.